@@ -32,6 +32,11 @@ class DiffReport:
     iter_len_mismatch: list[IterLenMismatch]
 
 def quickdiff(a: Any, b: Any) -> DiffReport:
+    """
+    
+    Arguments:
+        a {Any} -- 
+    """
     out = native_quickdiff(a, b) # type: ignore
     return DiffReport(
         val_changes=[ValChange(x.path, x.a, x.b) for x in out.val_changes], # type: ignore
